Tool Grid Widget (toolgrid)

# Tool Grid Widget (`toolgrid`)

A widget containing a grid of clickable actions/buttons.

class `orangecanvas.gui.toolgrid.` `ToolGrid`(parent=None, columns=4, buttonSize=None, iconSize=None, toolButtonStyle=3)

  Bases: `PyQt5.QtWidgets.QFrame`

  A widget containing a grid of actions/buttons.

  Actions can be added using standard `QWidget.addAction(QAction)()` and `QWidget.insertAction(int, QAction)()` methods.

  Parameters: | parent (`QWidget`) – Parent widget. columns (int) – Number of columns in the grid layout. buttonSize (`QSize`, optional) – Size of tool buttons in the grid. iconSize (`QSize`, optional) – Size of icons in the buttons. toolButtonStyle (`Qt.ToolButtonStyle`) – Tool button style.

  `actionTriggered`(QAction)

    Signal emitted when an action is triggered.

  `actionHovered`(QAction)

    Signal emitted when an action is hovered.

  `setButtonSize`(size)

    Set the button size.

  `buttonSize`()

    Return the button size.

  `setIconSize`(size)

    Set the button icon size.

  `iconSize`()

    Return the icon size

  `setToolButtonStyle`(style)

    Set the tool button style.

  `toolButtonStyle`()

    Return the tool button style.

  `setColumnCount`(columns)

    Set the number of button/action columns.

  `columns`()

    Return the number of columns in the grid.

  `clear`()

    Clear all actions/buttons.

  `insertAction`(before, action)

    Insert a new action at the position currently occupied by before (can also be an index).

    Parameters: | before (`QAction` or int) – Position where the action should be inserted. action (`QAction`) – Action to insert

  `setActions`(actions)

    Clear the grid and add actions.

  `buttonForAction`(action)

    Return the `QToolButton` instance button for action.

  `createButtonForAction`(action)

    Create and return a `QToolButton` for action.

  `count`()

    Return the number of buttons/actions in the grid.